#!/usr/bin/env bash
# ------------------------------------------------------------------------------
# Copyright 2023 Open Text.
#
# The only warranties for products and services of Open Text and its
# affiliates and licensors (“Open Text”) are as may be set forth in the
# express warranty statements accompanying such products and services.
# Nothing herein should be construed as constituting an additional
# warranty. Open Text shall not be liable for technical or editorial
# errors or omissions contained herein. The information contained herein
# is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains
# confidential information and a valid license is required for possession,
# use or copying. If this work is provided to the U.S. Government,
# consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items
# are licensed to the U.S. Government under vendor's standard commercial
# license.
# ------------------------------------------------------------------------------

SYSCONF="/etc/sysconfig/novell/umc"

if [ -e "$SYSCONF" ]; then
    source "$SYSCONF"
fi

# Check if the user is root
if [ "$EUID" -ne 0 ]; then
    echo "This script must be run as root."
    exit 1
fi

# Function to perform PostgreSQL database backup
backup_postgres_db() {

    if [ "$CONFIG_UMC_DB_HOSTNAME" == "$(hostname -f)" ]; then
        # Backup file name
        BACKUP_FILE="/tmp/postgres_backup.sql"

        # Perform the backup using pg_dumpall
        pg_dumpall -U postgres -f "$BACKUP_FILE"
    else
        echo "Postgres DB is not local"
    fi
}

# Check if SERVICE_CONFIGURED is set to "yes" in /etc/sysconfig/novell/umc
if [ "$SERVICE_CONFIGURED" == "yes" ]; then
    # Copy the config files to /tmp

    cp /opt/novell/umc/apps/umc-server/prod.env /tmp/umc_server_prod.env.bac
    cp /etc/sysconfig/novell/umc /tmp/umc_sysconfig.bac

    # Call the backup function
    backup_postgres_db
    exit 0
else
    echo "SERVICE_CONFIGURED is not set to 'yes' in /etc/sysconfig/novell/umc"
    exit 2
fi
