#!/usr/bin/env bash
# ------------------------------------------------------------------------------
# Copyright 2023 Open Text.
#
# The only warranties for products and services of Open Text and its
# affiliates and licensors (“Open Text”) are as may be set forth in the
# express warranty statements accompanying such products and services.
# Nothing herein should be construed as constituting an additional
# warranty. Open Text shall not be liable for technical or editorial
# errors or omissions contained herein. The information contained herein
# is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains
# confidential information and a valid license is required for possession,
# use or copying. If this work is provided to the U.S. Government,
# consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items
# are licensed to the U.S. Government under vendor's standard commercial
# license.
# ------------------------------------------------------------------------------

# Check if the user is root
if [ "$EUID" -ne 0 ]; then
    echo "Error: This script must be run as root."
    exit 1
fi

# Function to copy a file with an informative message
copy_file() {
    source_file="$1"
    destination_file="$2"
    if [ -f "$source_file" ]; then
        cp "$source_file" "$destination_file"
        echo "Copied $source_file to $destination_file"
    else
        echo "Error: $source_file is not present."
    fi
}

# Function to restore sysconfig from a backup file
restore_umc_sysconfig() {
    SYS_CONF_FILE='/etc/sysconfig/novell/umc'
    BAC_SYS_CONF_FILE='/tmp/umc_sysconfig.bac'
    if [ -f "$BAC_SYS_CONF_FILE" ]; then
        while IFS='=' read -r key value; do
            if [ -n "$key" ] && [ -n "$value" ]; then
                if [[ "$key" = "PATTERN_NAME" || "$key" = "YAST_CLIENT" ]]; then
                    continue
                fi
                value=$(sed -e 's/^"//' -e 's/"$//' <<<"$value")
                remove_value=$(grep -w $key $SYS_CONF_FILE | cut -d "=" -f2-)
                remove_value=$(sed -e 's/^"//' -e 's/"$//' <<<"$remove_value")
                # Check if remove_value is not empty, nil, or whitespace, then only run sysconf_addword -r
                if [ -n "$remove_value" ] && [ "$(echo -n "$remove_value" | tr -d '[:space:]')" != "nil" ]; then
                    $(sysconf_addword -r $SYS_CONF_FILE $key $remove_value)
                fi
                $(sysconf_addword $SYS_CONF_FILE $key $value)
                echo "Restored $key in $SYS_CONF_FILE from backup"
            fi
        done <"$BAC_SYS_CONF_FILE"
    else
        echo "Error: sysconfig backup file is not present in /tmp"
    fi
}

# Function to restore the Postgres DB
restore_db() {
    DB_PORT=$(grep -w 'CONFIG_UMC_DB_PORT=' /etc/sysconfig/novell/umc | cut -d "=" -f2- | cut -d "\"" -f 2)
    if [ -f "/tmp/postgres_backup.sql" ]; then
        cleanup_old_db
        /opt/novell/umc/scripts/postgres-setup.sh -p "$DB_PORT"
        psql -U postgres -f /tmp/postgres_backup.sql template1
        echo "Restored Postgres DB"
    else
        echo "Error: DB backup file is not present in /tmp"
    fi
}

# Clean up the postgres on target server before backing up from source
cleanup_old_db() {
    if [ -d ~postgres/data ]; then
        systemctl stop postgresql
        rm -r ~postgres/data
    fi
}

#Run migrate table script to place the table in umc db
migrate_table() {
    /usr/bin/python3 /opt/novell/umc/scripts/migrate_table.py
    /usr/bin/python3 /opt/novell/umc/scripts/umc-config.py update_conf_file
}

# Function to restart services
restart_services() {
    systemctl enable docker.service docker-edirapi.service
    systemctl restart postgresql.service microfocus-umc-server.service microfocus-umc-backend.service docker.service docker-edirapi.service
    echo "Restarted services"
}

# Check if UMC pattern is installed
if rpmqpack | grep patterns-oes-microfocus-umc; then
    restore_umc_sysconfig
    copy_file "/tmp/umc_server_prod.env.bac" "/opt/novell/umc/apps/umc-server/prod.env"
    restore_db
    migrate_table
    restart_services
    exit 0
else
    echo "Info: UMC Pattern is not installed. Skipping the migration."
fi
